@@ -1,3 +1,5 @@
+import warnings
+warnings.filterwarnings("ignore")
 
 import dash
 import dash_core_components as dcc
@@ -7,7 +9,6 @@ from dash.dependencies import Input, Output, State,MATCH, ALL
 #import arxiv
 import numpy as np
 import argparse
-import tqdm
 import os
 #from arxiv import SortOrder, SortCriterion
 import urllib
@@ -15,48 +16,105 @@ import feedparser
 import time
 import re
 import gzip, json
+import requests, socket
+
+if not os.path.isdir('arxivbox'):
+  os.mkdir('arxivbox')
+
+r = requests.get("http://paperswithcode.com/media/about/links-between-papers-and-code.json.gz")
+with open('arxivbox/links-between-papers-and-code.json.gz', 'wb') as f:
+  f.write(r.content)
+  f.close()
 
 
-keyword = 'iccv'
-confs = ['all', 'arXiv', 'CVPR', "ICCV", "ECCV", "WACV","AAAI","BMVC","NeurIPS","ICML","ICLR"]
+confs = ['all', 'arXiv', 'CVPR', "ICCV", "ECCV", "WACV", "AAAI", "BMVC", "NeurIPS", "ICML", "ICLR"]
 max_res = ['all', '100', '200', "300", "400", "500","1000","1500","2000","3000","4000"]
 options = ['strict', 'partly', 'all']
 sort = ['relevence', 'date']
 
-
 app = dash.Dash(external_stylesheets=[dbc.themes.BOOTSTRAP])
-app.title = 'paper-search'
+app.title = 'arxivbox'
 
 
-if not os.path.isfile('logfav'):
-  with open('logfav', 'w+') as f:
+if not os.path.isfile('arxivbox/logfav'):
+  with open('arxivbox/logfav', 'w+') as f:
     f.close()
 
 def loading(children):
   return dcc.Loading(children, type='cube', fullscreen=True, style={'opacity': 0.9})
 
-app.layout = dbc.Container([html.Br(),
+
+checklist = dbc.Form([dbc.FormGroup(
+    [
+        dbc.Label("Conference:", width =4),
+        dbc.Col(dbc.Select(id="select", style={ 'font-size': '12px',}, placeholder= 'venue',options=[{"label":i, "value":idx} for idx,i in enumerate(confs)] + [{"label":'other', 'value':-1}],value =0, ), width=5,),
+        dbc.Col(dbc.Input(placeholder= 'other, eg. EMNLP', id='other_conf',style={  'display':'none'},), width=9,),], row=True,),
+        
+        dbc.FormGroup([dbc.Label("Maximum results:", width =5),
+        dbc.Col(dbc.Select(id="select_max", style={ 'font-size': '12px'},placeholder= 'max',options=[{"label":i, "value":idx} for idx,i in enumerate(max_res)],value = 1,), width=4,)], row=True,),
+
+        dbc.FormGroup([dbc.Label("Matching method:", width =5),
+        dbc.Col(dbc.Select(id="select_option", style={ 'font-size': '12px'},placeholder= 'type',options=[{"label":i, "value":idx} for idx,i in enumerate(options)],value = 1,), width=4,)], row=True,),
+
+        dbc.FormGroup([dbc.Label("Sort by:", width =3),
+        dbc.Col(dbc.Select(id="select_sort", style={ 'font-size': '12px'},placeholder= 'sort',options=[{"label":i, "value":idx} for idx,i in enumerate(sort)],value = 1, ), width=6,)], row=True,),
+
+
+         dbc.FormGroup([dbc.Checkbox(id="code_option", className="form-check-input"), dbc.Label(
+                    "Show code-only results",
+                    html_for="code_option",
+                    className="form-check-label",
+                ),
+            ],
+            check=False, style = {'margin-left':  '20px'}
+        ),
+
+    ], style={ 'font-size': '12px',}
+)
+
+
+col2 = dbc.Container([html.Br(),
 
     dbc.InputGroup([dbc.InputGroupAddon(dbc.Checkbox(id = 'check-all'), addon_type="prepend"),
                     dbc.Input(placeholder= 'search anything', id='search_string', style={'width':'200px'}),
-                    dbc.Select(id="select",placeholder= 'venue',options=[{"label":i, "value":idx} for idx,i in enumerate(confs)],value =0, style={'width':'10px'}),
-                    dbc.Select(id="select_max",placeholder= 'max',options=[{"label":i, "value":idx} for idx,i in enumerate(max_res)],value = 1, style={'width':'10px'}),
-                    dbc.Select(id="select_option",placeholder= 'type',options=[{"label":i, "value":idx} for idx,i in enumerate(options)],value = 1),
-                    dbc.Select(id="select_sort",placeholder= 'sort',options=[{"label":i, "value":idx} for idx,i in enumerate(sort)],value = 1),
-                    dbc.InputGroupAddon("code", addon_type="prepend"),
-                    dbc.InputGroupAddon(dbc.RadioButton(id="code_option"), addon_type="prepend"),
-                    dbc.InputGroupAddon(dbc.Button("search", color="light", size = 'sm', id = 'search', className="mr-1")),], size="sm",style={'width':'700px'}
+                    #dbc.Select(id="select",placeholder= 'venue',options=[{"label":i, "value":idx} for idx,i in enumerate(confs)],value =0, style={'width':'10px'}),
+                    #dbc.Select(id="select_max",placeholder= 'max',options=[{"label":i, "value":idx} for idx,i in enumerate(max_res)],value = 1, style={'width':'10px'}),
+                    #dbc.Select(id="select_option",placeholder= 'type',options=[{"label":i, "value":idx} for idx,i in enumerate(options)],value = 1),
+                    #dbc.Select(id="select_sort",placeholder= 'sort',options=[{"label":i, "value":idx} for idx,i in enumerate(sort)],value = 1),
+                    #dbc.InputGroupAddon("code", addon_type="prepend"),
+                    #dbc.InputGroupAddon(dbc.RadioButton(id="code_option"), addon_type="prepend"),
+                    dbc.InputGroupAddon(dbc.Button("search", color="light", size = 'sm', id = 'search', className="mr-1")),], size="sm",style={'width':'500px'}
                     ),
 
 
     html.Br(),
     (html.Div(id='my-output')),
     html.Div(id='dummy'),
-    loading(html.Div(id='loadig'))
-
+    loading(html.Div(id='loadig')),
+    dbc.Tooltip('Show marked publications', target="check-all", placement = 'left'),
+    #dbc.Tooltip('Select conference name',target="select", placement = 'left'),
+    #dbc.Tooltip('Select maximum results',target="select_max", placement = 'left'),
+    #dbc.Tooltip('Select matching algorithm',target="select_option", placement = 'left'),
+    #dbc.Tooltip('Sort by', target="select_sort", placement = 'left'),
+    #dbc.Tooltip('Show results based on code availability', target="code_option", placement = 'left'),
 
 ], style =  {'align':'center', 'width':'800px'})
 
+app.layout = dbc.Container(dbc.Row(
+            [   dbc.Col(html.Div([html.Br(), html.Hr(), html.P('Advanced Options' , style={'font-size': '18px'}), html.Hr(), checklist, html.Hr(),])),
+                dbc.Col(col2),
+                
+ 
+            ],
+        ))
+
+@app.callback( Output(component_id = 'other_conf', component_property ='style'),Input(component_id = 'select', component_property ='value'),)
+def update(v):
+
+  if int(v) ==  -1:
+    return { 'font-size': '12px'}
+  else:
+    return {'display':'none'}
 
 @app.callback(
     [Output(component_id='my-output', component_property='children'),Output(component_id='loadig', component_property='children'),],
@@ -67,23 +125,24 @@ app.layout = dbc.Container([html.Br(),
      State(component_id='select_option', component_property='value'),
      State(component_id='select_sort', component_property='value'),
      State(component_id='code_option', component_property='checked'),
-     ]
-)
-def update_output_div(n_click, check_all, select_id, string, select_max, select_option, select_sort, code_option):
+     State(component_id='other_conf', component_property='value'),
+     ])
+
+def update_output_div(n_click, check_all, select_id, string, select_max, select_option, select_sort, code_option,other_conf):
 
   #with gzip.open('links-between-papers-and-code.json.gz', 'rt', encoding='UTF-8') as zipfile:
   #  pwcdata = json.load(zipfile)
 
-  with open('logfav', 'r') as f:
+  with open('arxivbox/logfav', 'r') as f:
     favlist = [ii[:-1][:-2] for ii in f.readlines()]
     f.close()
-  with open('logfav', 'r') as f:
+  with open('arxivbox/logfav', 'r') as f:
     favlistv = [ii[:-1] for ii in f.readlines()]
     f.close()
 
   #print (check_all)
 
-  with gzip.open('links-between-papers-and-code.json.gz', 'rt', encoding='UTF-8') as zipfile:
+  with gzip.open('arxivbox/links-between-papers-and-code.json.gz', 'rt', encoding='UTF-8') as zipfile:
     pwcdata = json.load(zipfile)
     pwcdata = {x['paper_arxiv_id']: x['repo_url'] for x in pwcdata}
     #print ('loading')
@@ -91,7 +150,10 @@ def update_output_div(n_click, check_all, select_id, string, select_max, select_
   if True:
 
      # print (confs, select_id)
-      conf = confs[int(select_id)]
+      if int(select_id)==-1:
+        conf = other_conf.upper()
+      else:
+        conf = confs[int(select_id)]
       max = max_res[int(select_max)]
       if max == 'all':
         max = float('inf')
@@ -140,7 +202,7 @@ def update_output_div(n_click, check_all, select_id, string, select_max, select_
 
       all_text = []
       count = 0
-      for idx, result in tqdm.tqdm(enumerate(search['entries'])):
+      for idx, result in enumerate(search['entries']):
         skip = False
 
         categories = result['arxiv_primary_category']['term']
@@ -178,6 +240,8 @@ def update_output_div(n_click, check_all, select_id, string, select_max, select_
         if skip ==True and conf == 'arXiv':
           continue
 
+        if int(select_id)==-1:
+          conf_name_show = conf
 
         author_list = authors#', '.join([au.name for au in result.authors])
         if arxiv_id.split('/abs/')[-1][:-2] in favlist:
@@ -338,7 +402,7 @@ def update_fav(checked):
       if dash.callback_context.triggered[0]['value'] == True:
         arxivid = dash.callback_context.triggered[0]['prop_id'].split('/abs/')[1].split('","type":"check-fav"')[0]
 
-        with open('logfav', 'a+') as f:
+        with open('arxivbox/logfav', 'a+') as f:
           f.write(arxivid + '\n')
           f.close()
 
@@ -347,7 +411,7 @@ def update_fav(checked):
         arxivid = dash.callback_context.triggered[0]['prop_id'].split('/abs/')[1].split('","type":"check-fav"')[0]
         #print (arxivid)
 
-        with open('logfav', 'r') as f:
+        with open('arxivbox/logfav', 'r') as f:
           favlist = [ii[:-1] for ii in f.readlines()]
           f.close()
 
@@ -357,7 +421,7 @@ def update_fav(checked):
 
         favlist = [i for j, i in enumerate(favlist) if i != arxivid]
 
-        with open('logfav', 'w+') as f:
+        with open('arxivbox/logfav', 'w+') as f:
           for i in favlist:
             f.write(i + '\n')
           f.close()
@@ -368,7 +432,11 @@ def update_fav(checked):
 
 
 if __name__ == '__main__':
-    app.run_server(debug=False)
+    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    sock.bind(('localhost', 0))
+    port = sock.getsockname()[1]
+    sock.close()
+    app.run_server(port=port, debug=False)
 
 
 
